/* --8<--8<--8<--8<--
 *
 * Copyright (C) 2007 Smithsonian Astrophysical Observatory
 *
 * This file is part of rdbplt
 *
 * rdbplt is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * rdbplt is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the 
 *       Free Software Foundation, Inc. 
 *       51 Franklin Street, Fifth Floor
 *       Boston, MA  02110-1301, USA
 *
 * -->8-->8-->8-->8-- */

#include <math.h>

#include <cpgplot.h>

#include <tracefct/tracefct.h>
#include <tracefct/exiterrvals.h>

#include "main.h"
#include "common.h"


void
get_limits( float *xmin, float *xmax, float *ymin, float *ymax )
{
  float pad;

  /* get some nice limits for the data */
  switch(c.limit_alg)
  {
  case LimitAlg_PGPLOT:
    cpgrnge( *xmin, *xmax, xmin, xmax );
    cpgrnge( *ymin, *ymax, ymin, ymax );

    break;

  case LimitAlg_NONE:
    break;

  case LimitAlg_PERCENT:
    pad = fabs(*xmax - *xmin) * c.limit_val;
    if ( *xmax > *xmin )
    {
      *xmax += pad;
      *xmin -= pad;
    }
    else
    {
      *xmax -= pad;
      *xmin += pad;
    }

    pad = fabs(*ymax - *ymin) * c.limit_val;
    if ( *ymax > *ymin )
    {
      *ymax += pad;
      *ymin -= pad;
    }
    else
    {
      *ymax -= pad;
      *ymin += pad;
    }
    break;

  default:
    tf_exit(ExitERR_misc, "%s:%d : internal error",
		    __FILE__, __LINE__);
  }

  if ( *xmin == *xmax )
  {
    tf_message( "xmin and xmax are the same: %f\n", *xmin );
    *xmin -= *xmin == 0.0 ? 0.1 : 0.1 * *xmin;
    *xmax += *xmax == 0.0 ? 0.1 : 0.1 * *xmax;
  } 

  if ( *ymin == *ymax )
  {
    tf_message( "ymin and ymax are the same: %f\n", *ymin );
    *ymin -= *ymin == 0.0 ? 0.1 : 0.1 * *ymin;
    *ymax += *ymax == 0.0 ? 0.1 : 0.1 * *ymax;
  }

}
